@@ -1,6 +1,6 @@
 '''
 Gauged
-https://github.com/chriso/gauged (GPL Licensed)
+https://github.com/chriso/gauged (MIT Licensed)
 Copyright 2014 (c) Chris O'Hara <cohara87@gmail.com>
 '''
 
@@ -17,4 +17,4 @@ class Aggregate(object):
 
     ALL = set(( SUM, MIN, MAX, MEAN, STDDEV, PERCENTILE, MEDIAN, COUNT ))
 
-    ASSOCIATIVE = set(( SUM, MIN, MAX, MEAN, COUNT ))
+    ASSOCIATIVE = set(( SUM, MIN, MAX, COUNT ))
