@@ -1,6 +1,6 @@
 /*!
  * Gauged
- * https://github.com/chriso/gauged (GPL Licensed)
+ * https://github.com/chriso/gauged (MIT Licensed)
  * Copyright 2014 (c) Chris O'Hara <cohara87@gmail.com>
  */
 
@@ -67,12 +67,6 @@ gauged_array_t *gauged_array_import(const float *, size_t);
 
 int gauged_array_append(gauged_array_t *, float);
 
-/**
- * Append an array of floats.
- */
-
-int gauged_array_concat(gauged_array_t *, const gauged_array_t *);
-
 /**
  * Sort the array.
  */
